#ifdef CONFIG_X86_64
#include "x86-32-syscalls-3.1.0-rc6_integers.h"
#endif

#ifdef CONFIG_ARM64
#include "arm-32-syscalls-3.4.25_integers.h"
#endif

#ifdef CONFIG_PPC64
#include "powerpc-32-syscalls-3.0.34_integers.h"
#endif
